@@ -20,8 +20,6 @@
 #ifndef __DESTINATION_H__
 #define __DESTINATION_H__
 
-#include <linux/netfilter_ipv4.h>
-#include <arpa/inet.h>
 #include <boost/asio.hpp>
 
 class IndeterminateDestinationException : public std::exception {
@@ -36,21 +34,7 @@ class Destination {
 public:
   
   static int getOriginalDestination(boost::asio::ip::tcp::socket &socket,
-				    boost::asio::ip::tcp::endpoint &originalDestination) 
-  {
-    struct sockaddr_in serverAddr;
-    int fd   = (int)socket.native();     
-    int size = sizeof(serverAddr);
-    
-    if (getsockopt(fd, SOL_IP, SO_ORIGINAL_DST, &serverAddr, (socklen_t*)&size) < 0) {
-      perror("Could not determine socket's original destination.");
-      throw IndeterminateDestinationException();
-    }
-
-    originalDestination = boost::asio::ip::tcp::endpoint(boost::asio::ip::address_v4(ntohl(serverAddr.sin_addr.s_addr)), ntohs(serverAddr.sin_port));
-    
-    return 1;
-  }
+				    boost::asio::ip::tcp::endpoint &originalDestination);
 };
 
 
